import pickle
from HPW_Tracing.Tracing import tracing_with_node
from HPW_Tracing.Tracing import create_mhNum_UFID_dict, tracing_with_node
import warnings
import pandas as pd
from time import time
warnings.filterwarnings("ignore")

db = 'C:\PythonProjects\__db'
datawarehouse_infrastrcuture  = r'C:\Users\C21252\City of Houston\WWIP Planning Data Warehouse - General\GIS Database\01_Infrastructure'
forceupdate = False
dict = create_mhNum_UFID_dict(db)


sub_graph = r'C:\Users\C21252\PycharmProjects\Sharepoints\_00_HPW_NetTracing\test\subgraph_test\ls_fm_subgraph_new.pick'
all_nodes = r'C:\Users\C21252\PycharmProjects\Sharepoints\_00_HPW_NetTracing\test\subgraph_test\all_nodes.pick'


with open(sub_graph, 'rb') as f:
    sub_graph = pickle.load(f)

with open(all_nodes, 'rb') as f:
    all_nodes = pickle.load(f)

nodeID = 'temp_59909'  # tracing starting node
direction = 'upstream'  # tracing direction
distance = None

node_dict,edges_df = tracing_with_node(sub_graph, dict, nodeID, direction, distance)


from HPW_Tracing.Build_graphs import iniciate_graph
from HPW_Tracing.Tracing import tracing_between_links
import warnings
import pandas as pd
from time import time
warnings.filterwarnings("ignore")

db = 'C:\PythonProjects\__db'
datawarehouse_infrastrcuture  = r'C:\Users\C21252\City of Houston\WWIP Planning Data Warehouse - General\GIS Database\01_Infrastructure'
forceupdate = False
G = iniciate_graph(db, datawarehouse_infrastrcuture, forceupdate)

start_link = '2509894'
end_link = '2509500'
nodes, edges = tracing_between_links(G, start_link, end_link)


from HPW_Tracing.Build_graphs import iniciate_graph

db = 'C:\\PythonProjects\\__db'
datawarehouse_infrastrcuture = 'C:\\Users\\C21252\\City of Houston\\WWIP Planning Data Warehouse - General\GIS Database\\01_Infrastructure'
forceupdate = False

G = iniciate_graph(db, datawarehouse_infrastrcuture, forceupdate)



db_folder = 'C:/Users/C21252/City of Houston/HWP-AIAP-TEAM - Documents/General/Working/Peng/Peng Work Final/__tracing_database'
datawarehouse = 'C:/Users/C21252/City of Houston/WWIP Planning Data Warehouse - General/GIS Database/01_Infrastructure'



from setuptools import setup, find_packages
import os
with open(os.path.join(os.path.dirname(__file__), 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# Read the contents of your requirements file
with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='HPW_Tracing',
    version='0.3.3',
    packages=find_packages(),
    include_package_data=True,
    package_data={'HPW_Tracing': ['config.py']},
    license='MIT',
    author='Peng Xie',
    author_email= 'xphn1985@gmail.com',
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.11',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.9',
    install_requires=required,
)



